@@ -34,8 +34,8 @@ class SentimentDataProcessor(DataProcessor):
 
 class SentimentTask(ExampleTaskBase):
     def __init__(self, taskArgs: TaskArguments = None):
-        super().__init__(taskArgs)
-        super().task_args.model_args.num_labels = 4
+        taskArgs.model_args.num_labels = 4
+        super().__init__('sentiment', taskArgs)
 
     def _data_processor(self):
         return SentimentDataProcessor(self.task_args.data_args)
